Stan Math Library: Namespace Members

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

- All
- Functions
- Variables
- Typedefs

- a
- b
- c
- d
- e
- f
- g
- h
- i
- j
- l
- m
- n
- o
- p
- q
- r
- s
- t
- u
- v
- w

Here is a list of all namespace members with links to the namespace documentation for each member:

### - u -

- ub_constrain() : stan::math
- ub_free() : stan::math
- uniform_ccdf_log() : stan::math
- uniform_cdf() : stan::math
- uniform_cdf_log() : stan::math
- uniform_log() : stan::math
- uniform_rng() : stan::math
- unit_vector_constrain() : stan::math
- unit_vector_free() : stan::math

[ Stan Home Page ] © 2011–2016, Stan Development Team.